#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for running the clustering analysis on a matrix.

@author: mark
"""

import logging
import scipy.cluster.hierarchy as cluster

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

def ward_clustering(triangular_distance_matrix):
    """This calculates the ward linkage for clustering.
    """
    return calculate_clustering(triangular_distance_matrix, "ward")

def wpgmc_clustering(triangular_distance_matrix):
    """This calculates the median/WPGMC linkage for clustering.
    """
    return calculate_clustering(triangular_distance_matrix, "median")

def upgmc_clustering(triangular_distance_matrix):
    """This calculates the centroid/UPGMC linkage for clustering.
    """
    return calculate_clustering(triangular_distance_matrix, "centroid")

def wpgma_clustering(triangular_distance_matrix):
    """This calculates the weighted/WPGMA linkage for clustering.
    """
    return calculate_clustering(triangular_distance_matrix,"weighted")

def upgma_clustering(triangular_distance_matrix):
    """This calculates the average/UPGMA linkage for clustering.
    """
    return calculate_clustering(triangular_distance_matrix, "average")

def max_clustering(triangular_distance_matrix):
    """This calculates the complete/max/farthest linkage for clustering.
    """
    return calculate_clustering(triangular_distance_matrix, "complete")

def min_clustering(triangular_distance_matrix):
    """This calculates the single/min/nearest linkage for clustering
    """
    return calculate_clustering(triangular_distance_matrix, "single")

def calculate_clustering(triangular_distance_matrix, method):
    """This calculates the clustering for the given input method.
    """
    return cluster.linkage(triangular_distance_matrix, method=method)
